# Development

This section describes how to install the software within a development
sandbox on your workstation, and how to run the software tests.


## Install Sandbox
Acquire source code and install development sandbox. The authors recommend
to use a Python virtualenv.
```shell
git clone https://github.com/crate/mlflow-cratedb
cd mlflow-cratedb
python3 -m venv .venv
source .venv/bin/activate
pip install --editable='.[examples,develop,docs,test]'
```


## Run Software Tests
Run linters and software tests, skipping slow tests:
```shell
poe check-fast
```

Exclusively run "slow" tests.
```shell
pytest -m slow
```


## Build OCI Images

If you are aiming to make changes to the software or to the `Dockerfile`, you can
build a local OCI image from the working tree on your workstation.

Run the following commands from the root directory of the project:
```shell
export DOCKER_BUILDKIT=1
export COMPOSE_DOCKER_CLI_BUILD=1
export BUILDKIT_PROGRESS=plain

docker build --tag=local/mlflow-cratedb --file=release/oci-server/Dockerfile .
docker build --tag=local/ml-runtime --file=release/oci-runtime/Dockerfile .
```


## Run a Release

```shell
git tag v0.x.x
git push && git push --tags
```

Build sdist and wheel packages, and upload them to PyPI.
```shell
poe release
```

Navigate to the [release page on GitHub], and announce the corresponding release,
adding the changelog items from the [](../CHANGES.md) file instead of the items
automatically generated by GitHub.


[release page on GitHub]: https://github.com/crate/mlflow-cratedb/releases
